# Test Inka

---
<!--ID:1708778405686-->
1. Test Entry from inka development:
> For manual tests
> data directory: '/Users/Q187392/Library/Application Support/Anki2'
> ```bash
> sqlite3 prefs21.db .dump > prefs21_dump.sql
> ```
> 
> <span style="font-size: 9pt;">This line will be rendered with 9pt font size.</span>

---
